<?php

namespace Drupal\user_audit\Commands;

use Drush\Commands\DrushCommands;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Drush command to return the configuration for failed login attempts.
 */
class FailedLoginSettings extends DrushCommands {

  /**
   * The flood settings
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $floodSettings;

  /**
   * Constructs a DrushCommand.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->floodSettings = $config_factory->get('user.flood');
  }
  /**
   * Display the settings for failed logins and lockout window.
   *
   * This commands validates NIST 800-53 control AC-7 (a) and AC-7 (b) and
   * SC-5.
   *
   * @command ct:failed-logins
   * @aliases ct-fl
   * @usage ct:failed-logins
   *   Get the settings for failed logins.
   */
  public function getLoginAttempts() {
    $loginAttempts = $this->floodSettings->get('user_limit');
    $this->output()->writeln('Failed logins: ' . $loginAttempts);
    $loginWindow = $this->floodSettings->get('user_window');
    $loginWindowTime = $loginWindow / 60;
    $this->output()->writeln('Lockout window: ' . $loginWindowTime . ' minutes');
    $ipAttempts = $this->floodSettings->get('ip_limit');
    $this->output()->writeln('IP failed logins: ' . $ipAttempts);
    $ipWindow = $this->floodSettings->get('ip_window');
    $ipWindowTime = $ipWindow / 60;
    $this->output()->writeln('IP lockout window: ' . $ipWindowTime . ' minutes');
  }

}
