<?php

namespace Drupal\user_audit\Commands;

use Drush\Commands\DrushCommands;
use Drupal\Core\Config\ConfigFactoryInterface;

/**
 * Drush command to return the configuration for email verification.
 */
class RequireVerification extends DrushCommands {

  /**
   * The flood settings
   *
   * @var \Drupal\Core\Config\Config
   */
  protected $userSettings;

  /**
   * Constructs a DrushCommand.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->userSettings = $config_factory->get('user.settings');
  }

  /**
   * Display the setting for require email verification.
   *
   * This commands validates NIST 800-53 control IA-4 (b).
   *
   * @command ct:email-verification
   * @aliases ct-ev
   * @usage ct:email-verification
   *   Get the setting for require email verification when a visitor creates an
   *   account.
   */
  public function getEmailVerification() {
    $setting = $this->userSettings->get('verify_mail');
    $verified = ($setting) ? 'true' : 'false';
    $this->output()->writeln('Email verification enabled: ' . $verified);
  }

}
